pub enum CustomBool {
True,
False,
Unspecified,
}Expand description
re-exports
Creates a custom boolean value with more features than a Rustlang boolean which has only true or false
Examples
let foo = CustomBool::Unspecified;
assert_eq!(foo, CustomBool::Unspecified);Variants
True
Similar to boolean true
False
Similar to boolean false
Unspecified
Status of an operation is not initialized